@@ -13,6 +13,7 @@
 #    under the License.
 
 import datetime
+import io
 import os
 import re
 import signal
@@ -24,7 +25,6 @@ from unittest import mock
 import fixtures
 import greenlet
 from oslotest import base
-import six
 
 import oslo_config
 from oslo_config import fixture
@@ -37,7 +37,7 @@ CONF = oslo_config.cfg.CONF
 opts.set_defaults(CONF)
 
 
-class FakeVersionObj(object):
+class FakeVersionObj:
     def vendor_string(self):
         return 'Cheese Shoppe'
 
@@ -59,7 +59,7 @@ def skip_body_lines(start_line, report_lines):
 
 class GmrConfigFixture(fixture.Config):
     def setUp(self):
-        super(GmrConfigFixture, self).setUp()
+        super().setUp()
 
         self.conf.set_override(
             'file_event_handler',
@@ -77,7 +77,7 @@ class GmrConfigFixture(fixture.Config):
 
 class TestGuruMeditationReport(base.BaseTestCase):
     def setUp(self):
-        super(TestGuruMeditationReport, self).setUp()
+        super().setUp()
 
         self.curr_g = greenlet.getcurrent()
 
@@ -189,7 +189,7 @@ class TestGuruMeditationReport(base.BaseTestCase):
     def test_register_autorun(self):
         gmr.TextGuruMeditation.setup_autorun(FakeVersionObj())
         self.old_stderr = sys.stderr
-        sys.stderr = six.StringIO()
+        sys.stderr = io.StringIO()
 
         os.kill(os.getpid(), signal.SIGUSR2)
         self.assertIn('Guru Meditation', sys.stderr.getvalue())
@@ -236,12 +236,12 @@ class TestGuruMeditationReport(base.BaseTestCase):
         run_mock.side_effect = RunFail()
         gmr.TextGuruMeditation.setup_autorun(FakeVersionObj())
         self.old_stderr = sys.stderr
-        sys.stderr = six.StringIO()
+        sys.stderr = io.StringIO()
 
         os.kill(os.getpid(), signal.SIGUSR2)
         self.assertIn('RunFail', sys.stderr.getvalue())
 
     def tearDown(self):
-        super(TestGuruMeditationReport, self).tearDown()
+        super().tearDown()
         if self.old_stderr is not None:
             sys.stderr = self.old_stderr
